@@ -268,6 +268,10 @@ class MintStick:
 
         self.devicelist.set_model(self.devicemodel)
 
+        itererator = self.devicemodel.get_iter_first()
+        if itererator is not None:
+            self.devicelist.set_active_iter(itererator)
+
     def device_selected(self, widget):
         iterator = self.devicelist.get_active_iter()
         if iterator is not None:
@@ -415,13 +419,19 @@ class MintStick:
         str_progress = "%3.0f%%" % (float(size) * 100)
         int_progress = int(float(size) * 100)
         self.progressbar.set_text(str_progress)
-        self.window.set_title("%s - %s" % (str_progress, _("USB Image Writer")))
+        if self.mode == "normal":
+            self.window.set_title("%s - %s" % (str_progress, _("USB Image Writer")))
+        else:
+            self.window.set_title("%s - %s" % (str_progress, _("USB Stick Formatter")))
         XApp.set_window_progress_pulse(self.window, False)
         XApp.set_window_progress(self.window, int_progress)
 
     def pulse_progress(self):
         self.progressbar.pulse()
-        self.window.set_title(_("USB Image Writer"))
+        if self.mode == "normal":
+            self.window.set_title( _("USB Image Writer"))
+        else:
+            self.window.set_title( _("USB Stick Formatter"))
         XApp.set_window_progress_pulse(self.window, True)
 
     def update_progress(self, fd, condition):
@@ -523,7 +533,10 @@ class MintStick:
         self.devicelist.set_sensitive(False)
         self.go_button.set_sensitive(False)
         self.progressbar.set_sensitive(False)
-        self.window.set_title(_("USB Image Writer"))
+        if self.mode == "normal":
+            self.window.set_title(_("USB Image Writer"))
+        else:
+            self.window.set_title(_("USB Stick Formatter"))     
 
     def close(self, widget):
         self.write_logfile()
